@@ -6,7 +6,7 @@ from subprocess import Popen, PIPE
 from sys import platform, exit
 
 
-__version__ = "0.1.13"
+__version__ = "0.1.14"
 
 gunicorns = {} # gunicorn master process names/pids.
 selected_pid = None # Process ID of currently selected gunicorn master process.
@@ -14,7 +14,7 @@ screen_delay = .1 # Seconds between screen updates.
 ps_delay = 2 # Seconds between ps updates.
 tick = -1 # Internal counter incremented in main event loop.
 title = "(`\._./`\._.-> gunicorn-console <-._./`\._./`)"
-instructions = """(r)eload master | (a)dd worker
+instructions = """(r)eload master | (t)otal reload | (a)dd worker
 kill (w)orker | kill (m)aster | (q)uit
 up/down changes selection
 """
@@ -166,6 +166,12 @@ def handle_keypress(screen):
             send_signal("HUP")
             del gunicorns[selected_pid]
             selected_pid = None
+    elif key in ("T",):
+        for pid in gunicorns.copy().iterkeys():
+            selected_pid = pid
+            send_signal("HUP")
+            del gunicorns[selected_pid]
+            selected_pid = None
     elif key in ("M", "-"):
         if selected_pid in gunicorns:
             send_signal("QUIT")
@@ -175,7 +181,7 @@ def handle_keypress(screen):
         raise KeyboardInterrupt
 
 
-def format_row(pid="", port="", name="", mem="", workers="", prefix_char=" "):
+def format_row(pid="", port="", name="", mem="", workers="", prefix_char="  "):
     """
     Applies consistant padding to each of the columns in a row and serves as
     the source of the overall screen width.
